/*******************************************************************************
*   File:	astropci_io.h
*   Author: 	Scott Streit
*   Abstract: 	I/O control commands for Solaris device driver for the SDSU PCI
*             	Interface Card. These commands are for use with ioctl().
*
*
*   Revision History:     Date      Who   Version    Description
*   --------------------------------------------------------------------------
*                       11/12/99    sds     1.0      Initial Release
*
*******************************************************************************/ 
#ifndef __ASTRO_IO_H__
#define __ASTRO_IO_H__

/*********************************************
	Information retrieval commands
*********************************************/
#define ASTROPCI_GET_REPLY		0x3
#define ASTROPCI_GET_HCTR		0x5
#define ASTROPCI_GET_HSTR		0x6
#define ASTROPCI_GET_PROGRESS		0x7
#define ASTROPCI_GET_CONFIG_INFO        0x314

/*********************************************
	Information set commands
*********************************************/
#define ASTROPCI_SET_CMDR  		0x100
#define ASTROPCI_SET_ARG1 	        0x105
#define ASTROPCI_SET_ARG2 	        0x106
#define ASTROPCI_SET_ARG3 	        0x107
#define ASTROPCI_SET_ARG4 	        0x108
#define ASTROPCI_SET_ARG5 	        0x109
#define ASTROPCI_SET_ARGS 	        0x110
#define ASTROPCI_SET_DESTINATION	0x111
#define ASTROPCI_SET_HCTR 	        0x115
#define ASTROPCI_SET_HCVR 	        0x117
#define ASTROPCI_SET_EXPTIME 	        0x119
#define ASTROPCI_SET_NCOLS 	        0x120
#define ASTROPCI_SET_NROWS 	        0x121
#define ASTROPCI_SET_IMAGE_BUFFERS	0x122
#define ASTROPCI_SET_UTIL_OPTIONS	0x123
#define ASTROPCI_ABORT_READ		0x302
#define ASTROPCI_FLUSH_REPLY_BUFFER	0x124
#define ASTROPCI_SET_BINNING_COLS	0x125
#define ASTROPCI_SET_BINNING_ROWS	0x126

/*********************************************
	Generic Constants
*********************************************/
#define DEBUG				0
#define BUFFER_OK_MASK			0x2	/* was 0x1 */
#define REPLY_BUFFER_EMPTY		-1

/*********************************************
	DSP Replies
*********************************************/
#define DON				0x00444F4E
#define ERR				0x00455252
#define TIMEOUT				0x544F5554

/*********************************************
	Interrupt constants
*********************************************/
#define REPLY_INTERRUPT			0x8
#define IMAGE_BUFFER1_INTERRUPT		0x10
#define IMAGE_BUFFER2_INTERRUPT		0x20
#define CLEAR_REPLY_INTERRUPT		0x8073
#define CLEAR_IMAGE_BUFF1_INTERRUPT	0x8075
#define CLEAR_IMAGE_BUFF2_INTERRUPT	0x8077
#define DMA_INTERRUPTING		0x40
#define ABORT_INTERRUPT			0x78
#define REPLY_DATA_EXISTS		0x4

/*********************************************
	DMA constants
*********************************************/
#define IMAGE_BUFF1_BUSY		0x10
#define IMAGE_BUFF1_CLEAR		0xFFFFFFEF
#define IMAGE_BUFF2_BUSY		0x20
#define IMAGE_BUFF2_CLEAR		0xFFFFFFDF

#endif

